## Controle de alterações

Documentação das principais alterações sofridas por este repositório. Baseado na filosofia [Mantenha um Changelog](https://keepachangelog.com/pt-BR/1.0.0/).

### [0.1.2] - 2021-12-21

- Especifica versões de dependências com >=
- Merge branch dev

### [0.1.1] - 2021-12-21

- Acrescenta função de validação e remoção colunas sqa e sqe

### [0.1.0] - 2021-12-15

- Otimiza função extract_resource

### [0.0.900] - 2021-12-13

- Criação do pacote
- Migração projeto etl-make - https://github.com/dados-mg/etl-make
